@@ -13,6 +13,7 @@ U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
 class Value1D:
     """Represents one dimension of a two-dimensional value.
     Should not be created manually, but gotten from a VariableList2D instance.
+    Do not set these to a variable, but retrieve them from an instance.
     """
 
     name: str
@@ -36,6 +37,9 @@ class Value1D:
         """
         return f"{self.name}: {self.with_unit}"
 
+    def __getitem__(self, key: int):
+        return self.values[key]
+
 
 class VariableList2D:
     def __init__(self, name: str, initial: np.ndarray):
